@@ -1,4 +1,4 @@
-#!D:\bld\digital_rf_1590786693207\_h_env\python.exe
+#!D:\bld\digital_rf_1591044018559\_h_env\python.exe
 # ----------------------------------------------------------------------------
 # Copyright (c) 2017 Massachusetts Institute of Technology (MIT)
 # All rights reserved.
@@ -20,7 +20,6 @@ Create a cross spectral time intensity summary plot for the given data sets.
 import datetime
 import itertools as it
 import optparse
-import string
 import sys
 import time
 import traceback
@@ -35,8 +34,6 @@ import pytz
 import scipy
 import scipy.signal
 
-matplotlib.rc("axes", hold=False)
-
 
 class DataPlotter:
     def __init__(self, control):
@@ -53,7 +50,7 @@ class DataPlotter:
 
         for idx, p in enumerate(self.control.path):
 
-            ch = string.split(self.control.channel[idx], ":")
+            ch = self.control.channel[idx].split(":")
             self.channel.append(ch[0])
             self.sub_channel.append(int(ch[1]))
 
@@ -217,13 +214,13 @@ class DataPlotter:
             # changes
             xmdf = self.dio[xidx].read_metadata(st0, et0, self.channel[xidx])
             try:
-                xmd = xmdf[xmdf.keys()[0]]
+                xmd = xmdf[list(xmdf.keys())[0]]
                 xcfreq = xmd["center_frequencies"].ravel()[self.sub_channel[xidx]]
             except (IndexError, KeyError):
                 xcfreq = 0.0
             ymdf = self.dio[yidx].read_metadata(st0, et0, self.channel[yidx])
             try:
-                ymd = ymdf[ymdf.keys()[0]]
+                ymd = ymdf[list(ymdf.keys())[0]]
                 ycfreq = ymd["center_frequencies"].ravel()[self.sub_channel[yidx]]
             except (IndexError, KeyError):
                 ycfreq = 0.0
@@ -249,7 +246,7 @@ class DataPlotter:
 
                 sti_times = np.zeros([self.control.bins], np.complex128)
 
-                for b in np.arange(self.control.bins):
+                for b in np.arange(self.control.bins, dtype=np.int_):
 
                     if self.control.verbose:
                         print(
@@ -322,25 +319,17 @@ class DataPlotter:
 
                 Pss = sti_csd_data_coherence
                 Pss2 = sti_csd_data_phase
-                vmin = np.real(np.median(Pss) - 6.0)
-                vmax = np.real(
-                    np.median(Pss)
-                    + (np.max(Pss) - np.median(Pss)) * 0.61803398875
-                    + 50.0
-                )
                 vmin2 = -np.pi * 1.05
                 vmax2 = np.pi * 1.05
 
                 if self.control.zaxis:
-                    vmin = int(string.split(self.control.zaxis, ":")[0])
-                    vmax = int(string.split(self.control.zaxis, ":")[1])
+                    vmin = int(self.control.zaxis.split(":")[0])
+                    vmax = int(self.control.zaxis.split(":")[1])
                 else:
-                    vmin = np.real(np.median(Pss) - 6.0)
-                    vmax = np.real(
-                        np.median(Pss)
-                        + (np.max(Pss) - np.median(Pss)) * 0.61803398875
-                        + 50.0
-                    )
+                    med_Pss = np.nanmedian(Pss)
+                    max_Pss = np.nanmax(Pss)
+                    vmin = np.real(med_Pss - 6.0)
+                    vmax = np.real(med_Pss + (max_Pss - med_Pss) * 0.61803398875 + 50.0)
 
                 im = ax.imshow(
                     Pss,
@@ -368,7 +357,10 @@ class DataPlotter:
                 # plot dates
 
                 tick_spacing = np.arange(
-                    self.control.bins / 8, self.control.bins, self.control.bins / 8
+                    self.control.bins / 8,
+                    self.control.bins,
+                    self.control.bins / 8,
+                    dtype=np.int_,
                 )
                 ax.set_xticks(tick_spacing)
                 ax1.set_xticks(tick_spacing)
